pytest-colordots
================

Colorizes the progress indicators

This is an adoption of [pytest-greendots](https://pypi.python.org/pypi/pytest-greendots)
which sadly does not have an upstream repository.

Usage
-----

Install with:

    pip install -U pytest-colordots

and then run your test suite:

    py.test

and marvel at all the pretty colors
